@@ -1,5 +1,5 @@
 package Test::Mock::Wrapper;
-$Test::Mock::Wrapper::VERSION = '0.02';
+$Test::Mock::Wrapper::VERSION = '0.03';
 use strict;
 use warnings;
 use base qw(Exporter);
@@ -138,6 +138,11 @@ sub getObject {
     return $self->{__mocked};
 }
 
+sub resetCalls {
+    my $self = shift;
+    $self->{__calls} = {};
+}
+
 sub _call {
     my $self = shift;
     my $method = shift;
@@ -312,7 +317,7 @@ sub verify {
 
 
 package Test::Mock::Wrapped;
-$Test::Mock::Wrapped::VERSION = '0.02';
+$Test::Mock::Wrapped::VERSION = '0.03';
 use Carp;
 use Scalar::Util qw(weaken isweak);
 use vars qw(@ISA);
